==> mediawiki_1.15.3.orig.tar.gz: mediawiki-1.15.3/languages/messages/MessagesAb.php <==
<?php
/** Abkhazian (Аҧсуа)
 *
 * See MessagesQqq.php for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Comp1089
 * @author Mzhiba
 * @author Temuri rajavi
 * @author ОйЛ
 */

$fallback = 'ru';

$messages = array(
# Dates
'sunday'       => 'амҽыш',
'monday'       => 'ашәахь',
'tuesday'      => 'аҩаш',
'wednesday'    => 'ахаш',
'thursday'     => 'аҧшьаш',
'friday'       => 'ахәуаш',
'saturday'     => 'асабш',
'january'      => 'ажьырныҳәа',
'february'     => 'жәабран',
'march'        => 'хәажәкыр',
'april'        => 'мшаҧы',
'may_long'     => 'лаҵара',
'june'         => 'рашәара',
'july'         => 'ҧхынгәы',
'august'       => 'нанҳәа',
'september'    => 'цәыббра',
'october'      => 'жьҭаара',
'november'     => 'абҵара',
'december'     => 'ҧхынҷкәын',
'january-gen'  => 'ажьырныҳәа',
'february-gen' => 'жәабран',

# Categories related messages
'pagecategories' => '{{PLURAL:$1|Акатегориа|Акатегориақәа}}',

'article'        => 'Адаҟьа',
'qbedit'         => 'Ариашара',
'qbpageoptions'  => 'Ари адаҟьа',
'qbspecialpages' => 'Цастәи адаҟьақәа',
'navigation'     => 'Анавигациа',

'help'             => 'Ацхыраара',
'search'           => 'Аҧшаара',
'searchbutton'     => 'Аҧшаара',
'searcharticle'    => 'Адаҟьа',
'history'          => 'Аҭоурых',
'history_short'    => 'Аҭоурых',
'printableversion' => 'Акьыҧхьразы аверсиа',
'permalink'        => 'Еисымшатәи ахьарҧш',
'edit'             => 'Ариашамҭа',
'create'           => 'Арҿиара',
'talkpagelinktext' => 'Ахцәажәара',
'specialpage'      => 'Цастәи адаҟьа',
'talk'             => 'Ахцәажәара',
'toolbox'          => 'Амаҵыругақәа',
'lastmodifiedat'   => 'Ацыхәтәантәи аҧсахрақәа абри адаҟьа аҟны: $2, $1.', # $1 date, $2 time
'jumptonavigation' => 'Анавигациа',
'jumptosearch'     => 'Аҧшаара',

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
'aboutsite'            => '{{SITENAME}} иазкны',
'currentevents'        => 'Ииасуа ахҭысқәа',
'mainpage'             => 'Ихадоу Адаҟьа',
'mainpage-description' => 'Ихадоу адаҟьа',
'privacy'              => 'Аконфиденциалтә аполитика',
'privacypage'          => 'Project: Аконфиденциалтә аполитика',

'editsection' => 'ариашамҭа',
'editold'     => 'ариашара',
'editlink'    => 'ариашара',

# Short words for each namespace, by default used in the namespace tab in monobook
'nstab-main'     => 'Адаҟьа',
'nstab-user'     => 'Иалахә',
'nstab-special'  => 'Цастәи адаҟьа',
'nstab-template' => 'Ашаблон',
'nstab-help'     => 'Ацхыраара',
'nstab-category' => 'Акатегориа',

# General errors
'viewsource' => 'Ахәаҧшра',

# Login and logout pages
'uid'                => 'Иалоу ID:',
'yourlanguage'       => 'Абызшәа:',
'loginlanguagelabel' => 'Бызшәа: $1',

# Edit pages
'summary'     => 'Ятарлă саспаллисем:',
'savearticle' => 'Адаҟьа ахьчара',

# Groups
'group-user' => 'Иалоуқәа',

'group-user-member' => 'Иалахә',

# Recent changes
'recentchanges' => 'Аҽыц риашарақәа',

# Recent changes linked
'recentchangeslinked' => 'Еимадоу ариашарақәа',

# File description page
'filehist-user' => 'Иалоу',

# Random page
'randompage' => 'Машәырлатәи аҩымҭа',

# Miscellaneous special pages
'newpages-username' => 'Иалахә:',

# Special:Log
'specialloguserlabel' => 'Иалахә:',

# Special:AllPages
'alphaindexline' => '$1 ... $2',

# Special:LinkSearch
'linksearch-ok' => 'Аҧшаара',

# Restrictions (nouns)
'restriction-edit' => 'Ариашамҭа',

'sp-contributions-submit' => 'Аҧшаара',

# What links here
'whatlinkshere'      => 'Арахьтәи ахьарҧшқәа',
'whatlinkshere-page' => 'Адаҟьа:',

# Special:NewFiles
'ilsubmit' => 'Аҧшаара',

# 'all' in various places, this might be different for inflected languages
'watchlistall2' => 'зегьы',
'namespacesall' => 'зегьы',
'monthsall'     => 'зегьы',

# Special:FileDuplicateSearch
'fileduplicatesearch-submit' => 'Аҧшаара',

);

==> mediawiki-1.15.4.tar.gz: mediawiki-1.15.4/languages/messages/MessagesAb.php <==
<?php
/** Abkhazian (Аҧсуа)
 *
 * See MessagesQqq.php for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Comp1089
 * @author Mzhiba
 * @author Temuri rajavi
 * @author ОйЛ
 */

$fallback = 'ru';

$messages = array(
# Dates
'sunday'       => 'амҽыш',
'monday'       => 'ашәахь',
'tuesday'      => 'аҩаш',
'wednesday'    => 'ахаш',
'thursday'     => 'аҧшьаш',
'friday'       => 'ахәуаш',
'saturday'     => 'асабш',
'january'      => 'ажьырныҳәа',
'february'     => 'жәабран',
'march'        => 'хәажәкыр',
'april'        => 'мшаҧы',
'may_long'     => 'лаҵара',
'june'         => 'рашәара',
'july'         => 'ҧхынгәы',
'august'       => 'нанҳәа',
'september'    => 'цәыббра',
'october'      => 'жьҭаара',
'november'     => 'абҵара',
'december'     => 'ҧхынҷкәын',
'january-gen'  => 'ажьырныҳәа',
'february-gen' => 'жәабран',

# Categories related messages
'pagecategories' => '{{PLURAL:$1|Акатегориа|Акатегориақәа}}',

'article'        => 'Адаҟьа',
'qbfind'         => 'Аҧшаара',
'qbedit'         => 'Ариашара',
'qbpageoptions'  => 'Ари адаҟьа',
'qbspecialpages' => 'Цастәи адаҟьақәа',
'navigation'     => 'Анавигациа',

'help'             => 'Ацхыраара',
'search'           => 'Аҧшаара',
'searchbutton'     => 'Аҧшаара',
'searcharticle'    => 'Адаҟьа',
'history'          => 'Аҭоурых',
'history_short'    => 'Аҭоурых',
'printableversion' => 'Акьыҧхьразы аверсиа',
'permalink'        => 'Еисымшатәи ахьарҧш',
'edit'             => 'Ариашамҭа',
'create'           => 'Арҿиара',
'newpage'          => 'Адаҟьа Ҿыц',
'talkpagelinktext' => 'Ахцәажәара',
'specialpage'      => 'Цастәи адаҟьа',
'talk'             => 'Ахцәажәара',
'toolbox'          => 'Амаҵыругақәа',
'otherlanguages'   => 'Абызшәақәа',
'lastmodifiedat'   => 'Ацыхәтәантәи аҧсахрақәа абри адаҟьа аҟны: $2, $1.', # $1 date, $2 time
'jumptonavigation' => 'Анавигациа',
'jumptosearch'     => 'Аҧшаара',

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
'aboutsite'            => '{{SITENAME}} иазкны',
'currentevents'        => 'Ииасуа ахҭысқәа',
'mainpage'             => 'Ихадоу Адаҟьа',
'mainpage-description' => 'Ихадоу адаҟьа',
'privacy'              => 'Аконфиденциалтә аполитика',
'privacypage'          => 'Project: Аконфиденциалтә аполитика',

'editsection' => 'ариашамҭа',
'editold'     => 'ариашара',
'editlink'    => 'ариашара',

# Short words for each namespace, by default used in the namespace tab in monobook
'nstab-main'     => 'Адаҟьа',
'nstab-user'     => 'Иалахә',
'nstab-special'  => 'Цастәи адаҟьа',
'nstab-image'    => 'Афаил',
'nstab-template' => 'Ашаблон',
'nstab-help'     => 'Ацхыраара',
'nstab-category' => 'Акатегориа',

# General errors
'viewsource' => 'Ахәаҧшра',

# Login and logout pages
'uid'                => 'Иалоу ID:',
'yourlanguage'       => 'Абызшәа:',
'loginlanguagelabel' => 'Бызшәа: $1',

# Edit pages
'summary'     => 'Ятарлă саспаллисем:',
'savearticle' => 'Адаҟьа ахьчара',
'editing'     => 'Ариашамҭа: $1',

# Groups
'group-user' => 'Иалоуқәа',

'group-user-member' => 'Иалахә',

# Recent changes
'recentchanges' => 'Арҽеира ҿыцқәа',

# Recent changes linked
'recentchangeslinked' => 'Еимадоу ариашарақәа',

# File description page
'filehist-user' => 'Иалоу',

# Random page
'randompage' => 'Машәырлатәи аҩымҭа',

# Miscellaneous special pages
'newpages-username' => 'Иалахә:',

# Special:Log
'specialloguserlabel' => 'Иалахә:',

# Special:AllPages
'alphaindexline' => '$1 ... $2',

# Special:LinkSearch
'linksearch-ok' => 'Аҧшаара',

# Restrictions (nouns)
'restriction-edit' => 'Ариашамҭа',

'sp-contributions-submit' => 'Аҧшаара',

# What links here
'whatlinkshere'      => 'Арахьтәи ахьарҧшқәа',
'whatlinkshere-page' => 'Адаҟьа:',

# Special:NewFiles
'ilsubmit' => 'Аҧшаара',

# 'all' in various places, this might be different for inflected languages
'watchlistall2' => 'зегьы',
'namespacesall' => 'зегьы',
'monthsall'     => 'зегьы',

# Special:FileDuplicateSearch
'fileduplicatesearch-submit' => 'Аҧшаара',

# Special:SpecialPages
'specialpages' => 'Цастәи адаҟьақәа',

);
